@@ -1,19 +1,25 @@
 package detector
 
 import (
+	"io/ioutil"
 	"talisman/detector/helpers"
 	"talisman/detector/severity"
 	"talisman/gitrepo"
 	"talisman/talismanrc"
 	"testing"
 
+	logr "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 )
 
+func init() {
+	logr.SetOutput(ioutil.Discard)
+}
+
 type FailingDetection struct{}
 
 func (v FailingDetection) Test(comparator helpers.ChecksumCompare, currentAdditions []gitrepo.Addition, ignoreConfig *talismanrc.TalismanRC, result *helpers.DetectionResults, additionCompletionCallback func()) {
-	result.Fail("some_file", "filecontent", "FAILED BY DESIGN", []string{}, severity.Low())
+	result.Fail("some_file", "filecontent", "FAILED BY DESIGN", []string{}, severity.Low)
 }
 
 type PassingDetection struct{}
@@ -23,7 +29,7 @@ func (p PassingDetection) Test(comparator helpers.ChecksumCompare, currentAdditi
 
 func TestEmptyValidationChainPassesAllValidations(t *testing.T) {
 	v := NewChain()
-	results := helpers.NewDetectionResults()
+	results := helpers.NewDetectionResults(talismanrc.HookMode)
 	v.Test(nil, &talismanrc.TalismanRC{}, results)
 	assert.False(t, results.HasFailures(), "Empty validation chain is expected to always pass")
 }
@@ -32,7 +38,7 @@ func TestValidationChainWithFailingValidationAlwaysFails(t *testing.T) {
 	v := NewChain()
 	v.AddDetector(PassingDetection{})
 	v.AddDetector(FailingDetection{})
-	results := helpers.NewDetectionResults()
+	results := helpers.NewDetectionResults(talismanrc.HookMode)
 	v.Test(nil, &talismanrc.TalismanRC{}, results)
 
 	assert.False(t, results.Successful(), "Expected validation chain with a failure to fail.")
